@@ -1,14 +1,8 @@
+# $Id: i.pm 787 2007-12-02 05:04:55Z gene $
 package Date::Baha::i;
-
-use vars qw($VERSION);
-$VERSION = '0.16';
-
-# FYI: The {{{ and }}} things are "editor code fold" markers.  They are
-# merely a convenience for people who don't care to scroll through
-# reams of source, like me.
-
-# Package declarations {{{
+our $VERSION = '0.1601';
 use strict;
+use warnings;
 use base 'Exporter';
 use vars qw(@EXPORT @EXPORT_OK);
 @EXPORT = @EXPORT_OK = qw(
@@ -33,9 +27,9 @@ use Date::Calc qw(
 use Time::Zone;
 use Lingua::EN::Numbers::Ordinate;
 use Lingua::EN::Numbers qw(American);
-# }}}
 
-# Set constants {{{
+
+# Set constants
 use constant FACTOR         =>   19;  # Everything is in groups of 19.
 use constant FEBRUARY       =>    2;
 use constant MARCH          =>    3;
@@ -145,18 +139,18 @@ use constant HOLY_DAYS => {
     "Day of the Covenant"       => [ '11.26' ],
     "Ascension of 'Abdu'l-Baha" => [ '11.28' ],
 };
-# }}}
 
-# List return functions {{{
+
+# List return functions
 sub cycles { return CYCLE_YEAR }
 sub years { return CYCLE_YEAR }
 sub months { return MONTH_DAY }
 sub days { return (MONTH_DAY)[0 .. 18] }
 sub days_of_the_week { return DOW_NAME }
 sub holy_days { return HOLY_DAYS }
-# }}}
 
-sub to_bahai {  # {{{
+
+sub to_bahai {
     my %args = @_;
 
     # Grab the ymd from the arguments if they have been passed in.
@@ -189,9 +183,9 @@ sub to_bahai {  # {{{
         %args
     );
 }
-# }}}
 
-sub from_bahai {  # {{{
+
+sub from_bahai {
     my %args = @_;
 
     # Figure out the year.
@@ -211,9 +205,9 @@ sub from_bahai {  # {{{
     return wantarray
         ? ($year, $month, $day)
         : join '/', $year, $month, $day;
-}  # }}}
+}
 
-sub as_string {  # {{{
+sub as_string {
     # XXX With Lingua::EN::Numbers, naively assume that we only care
     # about English.
     my($date_hash, %args) = @_;
@@ -328,9 +322,9 @@ sub as_string {  # {{{
     }
 
     return $date;
-}  # }}}
+}
 
-sub next_holy_day {  # {{{
+sub next_holy_day {
     my($year, $month, $day) = @_;
 
     # Use today if we are not provided with a date.
@@ -365,11 +359,11 @@ sub next_holy_day {  # {{{
     return wantarray
         ? ($inverted{$holy_date}, $date)
         : "$inverted{$holy_date} $date";
-}  # }}}
+}
 
-# Helper functions {{{
+# Helper functions
 # Date comparison gymnastics.
-sub _setup_date_comparison {  # {{{
+sub _setup_date_comparison {
     my($y, $m, $d, $s, $e) = @_;
 
     # Dates are encoded as decimals.
@@ -392,9 +386,9 @@ sub _setup_date_comparison {  # {{{
         Date_to_Days($y, $m, $d),
         Date_to_Days($start_year, $start_month, $start_day),
         Date_to_Days($end_year, $end_month, $end_day);
-}  # }}}
+}
 
-sub _build_date {  # {{{
+sub _build_date {
     my($year, $month, $day, $new_month, $new_day, %args) = @_;
 
     my %date;
@@ -440,9 +434,9 @@ sub _build_date {  # {{{
     $date{holy_day} = $inverted{$m_d} if exists $inverted{$m_d};
 
     return wantarray ? %date : as_string(\%date, %args);
-}  # }}}
+}
 
-sub _invert_holy_days {  # {{{
+sub _invert_holy_days {
     my $year = shift || (localtime)[5] + ADJUST_YEAR;
 
     my %inverted;
@@ -467,10 +461,10 @@ sub _invert_holy_days {  # {{{
     }
 
     return %inverted;
-}  # }}}
+}
 
 # Return a ymd date array but try to honor the epoch and use_gmtime settings.
-sub _ymd {  # {{{
+sub _ymd {
     my %args = @_;
 
     # Use the system time, if a ymd is not provided.
@@ -485,8 +479,8 @@ sub _ymd {  # {{{
     }
 
     return $args{year}, $args{month}, $args{day};
-}  # }}}
-# }}}
+}
+
 
 1;
 __END__
@@ -1035,6 +1029,6 @@ it under the same terms as Perl itself.
 
 =head1 CVS
 
-$Id: i.pm,v 1.8 2004/02/26 22:59:02 gene Exp $
+$Id: i.pm 787 2007-12-02 05:04:55Z gene $
 
 =cut
